@@ -24,33 +24,24 @@ MeasureSurvCalibrationBeta = R6Class("MeasureSurvCalibrationBeta",
   inherit = MeasureSurv,
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(se = FALSE) {
+    initialize = function() {
+      ps = ps(
+        se = p_lgl(default = FALSE)
+      )
+      ps$values$se = FALSE
+
       super$initialize(
-        id = ifelse(se, "surv.calib_beta_se", "surv.calib_beta"),
+        id = "surv.calib_beta",
         range = c(-Inf, Inf),
         minimize = FALSE,
         predict_type = "lp",
         man = "mlr3proba::mlr_measures_surv.calib_beta",
+        param_set = ps
       )
-
-      private$.se = assertFlag(se)
-    }
-  ),
-
-  active = list(
-    #' @field se `(logical(1))` \cr
-    #' If `TRUE` returns the standard error of the measure.
-    se = function(x) {
-      if (!missing(x)) {
-        private$.se = assertFlag(x)
-      } else {
-        return(private$.se)
-      }
     }
   ),
 
   private = list(
-    .se = FALSE,
     .score = function(prediction, ...) {
 
       df = data.frame(truth = prediction$truth, lp = prediction$lp)
@@ -58,7 +49,7 @@ MeasureSurvCalibrationBeta = R6Class("MeasureSurvCalibrationBeta",
       if (class(fit)[1] == "try-error") {
         return(NA)
       } else {
-        if (self$se) {
+        if (self$param_set$values$se) {
           return(fit$coefficients[3])
         } else {
           return(fit$coefficients[1])
