@@ -14,8 +14,6 @@
 #' @template param_times
 #' @template param_thresh
 #' @template param_measure_type
-#' @template field_thresh
-#' @template field_measure_type
 #'
 #' @references
 #' `r format_bib("song_2008")`
@@ -27,61 +25,40 @@ MeasureSurvSongTPR = R6Class("MeasureSurvSongTPR",
   inherit = MeasureSurvAUC,
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
-    initialize = function(times = 0, lp_thresh = 0, type = c("incident", "cumulative")) {
-      assertNumeric(times, len = 1)
+    initialize = function() {
+      ps = ps(
+        times = p_dbl(0),
+        lp_thresh = p_dbl(default = 0),
+        type = p_fct(c("incident", "cumulative"), default = "incident")
+      )
+      ps$values = list(lp_thresh = 0, type = "incident")
 
       super$initialize(
-        integrated = FALSE,
-        times = times,
         id = "surv.song_tpr",
         properties = c("requires_task", "requires_train_set", "requires_learner"),
-        man = "mlr3proba::mlr_measures_surv.song_tpr"
+        man = "mlr3proba::mlr_measures_surv.song_tpr",
+        param_set = ps
       )
-
-      assertNumeric(lp_thresh, len = 1)
-      private$.lp_thresh = lp_thresh
-      private$.type = match.arg(type)
-    }
-  ),
-
-  active = list(
-    lp_thresh = function(lp_thresh) {
-      if (missing(lp_thresh)) {
-        return(private$.lp_thresh)
-      } else {
-        assertNumeric(lp_thresh, len = 1)
-        private$.lp_thresh = lp_thresh
-      }
-    },
-
-    type = function(type) {
-      if (missing(type)) {
-        return(private$.type)
-      } else {
-        type = c("incident", "cumulative")[pmatch(type, c("incident", "cumulative"))]
-        if (is.na(type)) {
-          stop("'type' must be on: 'incident', 'cumulative'. Abbreviations allowed.")
-        }
-        private$.type = type
-      }
     }
   ),
 
   private = list(
-    .lp_thresh = numeric(0),
-    .type = character(0),
     .score = function(prediction, learner, task, train_set, ...) {
+      if (is.null(self$param_set$values$times)) {
+        stop("`times` must be non-NULL")
+      }
+
       tpr = super$.score(
         prediction = prediction,
         learner = learner,
         task = task,
         train_set = train_set,
         FUN = survAUC::sens.sh,
-        type = self$type,
+        type = self$param_set$values$type,
         ...
       )
 
-      tpr[, findInterval(self$lp_thresh, sort(unique(prediction$lp)))]
+      tpr[, findInterval(self$param_set$values$lp_thresh, sort(unique(prediction$lp)))]
     }
   )
 )
