@@ -22,9 +22,14 @@ MeasureSurvUnoAUC = R6Class("MeasureSurvUnoAUC",
   public = list(
     #' @description Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function(integrated = TRUE, times) {
+      ps = ps(
+        integrated = p_lgl(default = TRUE),
+        times = p_uty()
+      )
+      ps$values$integrated = TRUE
+
       super$initialize(
-        integrated = integrated,
-        times = times,
+        param_set = ps,
         id = "surv.uno_auc",
         properties = c("requires_task", "requires_train_set"),
         man = "mlr3proba::mlr_measures_surv.uno_auc"
@@ -34,6 +39,16 @@ MeasureSurvUnoAUC = R6Class("MeasureSurvUnoAUC",
 
   private = list(
     .score = function(prediction, task, train_set, ...) {
+      ps = self$param_set$values
+      if (!ps$integrated) {
+        msg = "If `integrated=FALSE` then `times` should be a scalar numeric."
+        assert_numeric(ps$times, len = 1, .var.name = msg)
+      } else {
+        if (!is.null(ps$times) && length(ps$times) == 1) {
+          ps$integrated = FALSE
+        }
+      }
+
       super$.score(
         prediction = prediction,
         task = task,
