@@ -91,7 +91,7 @@ PipeOpCrankCompositor = R6Class("PipeOpCrankCompositor",
         param_vals = param_vals,
         input = data.table(name = "input", train = "NULL", predict = "PredictionSurv"),
         output = data.table(name = "output", train = "NULL", predict = "PredictionSurv"),
-        packages = "distr6"
+        packages = c("mlr3proba", "distr6")
       )
     }
   ),
