@@ -3,11 +3,11 @@ test_that("PipeOpCrankCompositor - basic properties", {
   expect_equal(PipeOpCrankCompositor$new()$param_set$values$method, "mean")
 })
 
-task = tgen("simsurv")$generate(20)
+task = tsk("rats")$filter(sample(300, 20))
 
 test_that("PipeOpCrankCompositor - estimate", {
   gr = mlr3pipelines::ppl("crankcompositor", lrn("surv.coxph"), method = "mode", which = 1)
-  expect_silent(gr$train(task))
+  suppressWarnings(gr$train(task))
   p = gr$predict(task)[[1]]
   expect_prediction_surv(p)
   expect_true("crank" %in% p$predict_types)
